@@ -42,7 +42,7 @@ Distributor::Distributor(QObject *parent)
 
     // setup network status tracking
     if (QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Reachability)) {
-        connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &Distributor::processNextCommand);
+        connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &Distributor::reachabilityChanged);
         connect(QNetworkInformation::instance(), &QNetworkInformation::isMeteredChanged, this, [this]{ setUrgency(determineUrgency()); });
     } else {
         qCWarning(Log) << "No network state information available!" << QNetworkInformation::availableBackends();
@@ -515,7 +515,7 @@ void Distributor::processNextCommand()
 
 void Distributor::doProcessNextCommand()
 {
-    if (hasCurrentCommand() || m_commandQueue.empty() || !isNetworkAvailable()) {
+    if (hasCurrentCommand() || m_commandQueue.empty() || (!isNetworkAvailable() && m_commandQueue.front().type != Command::Disconnect)) {
         return;
     }
 
@@ -854,4 +854,19 @@ void Distributor::retryTimeout()
     processNextCommand();
 }
 
+void Distributor::reachabilityChanged()
+{
+    qCDebug(Log) << QNetworkInformation::instance()->reachability();
+    if (isNetworkAvailable() && !m_clients.empty() && status() != DistributorStatus::Connected) {
+        Command cmd{ .type = Command::Connect };
+        m_commandQueue.push_back(std::move(cmd));
+    }
+    if (!isNetworkAvailable() && m_status == DistributorStatus::Connected) {
+        Command cmd{ .type = Command::Disconnect };
+        m_commandQueue.push_back(std::move(cmd));
+    }
+
+    processNextCommand();
+}
+
 #include "moc_distributor.cpp"
